#[hook]Expand description
Marks function as hook.
Depending on context it allows to run custom code on item before it registers stuff
#[hook]Marks function as hook.
Depending on context it allows to run custom code on item before it registers stuff